|wq.core|

`wq.core <https://wq.io/wq.core>`__ provides the core ``wq`` command
line application for use by `wq.app <https://wq.io/wq.app>`__ and other
modules in the `wq framework <https://wq.io/>`__.

|Latest PyPI Release| |Release Notes| |Documentation| |License| |GitHub
Stars| |GitHub Forks| |GitHub Issues|

|Travis Build Status|

Getting Started
---------------

.. code:: bash

    # Recommended: create virtual environment
    # python3 -m venv venv
    # . venv/bin/activate

    # Install entire wq suite (recommended)
    pip install wq

    # Install only wq.core
    pip install wq.core

Command Line Reference
----------------------

.. code:: bash

    wq --help

See `the documentation <https://wq.io/docs/wq>`__ for more information.

.. |wq.core| image:: https://raw.github.com/wq/wq/master/images/256/wq.core.png
   :target: https://wq.io/wq.core
.. |Latest PyPI Release| image:: https://img.shields.io/pypi/v/wq.core.svg
   :target: https://pypi.org/project/wq.core
.. |Release Notes| image:: https://img.shields.io/github/release/wq/wq.core.svg
   :target: https://github.com/wq/wq.core/releases
.. |Documentation| image:: https://img.shields.io/badge/Docs-1.1-blue.svg
   :target: https://wq.io/wq.core
.. |License| image:: https://img.shields.io/pypi/l/wq.core.svg
   :target: https://wq.io/license
.. |GitHub Stars| image:: https://img.shields.io/github/stars/wq/wq.core.svg
   :target: https://github.com/wq/wq.core/stargazers
.. |GitHub Forks| image:: https://img.shields.io/github/forks/wq/wq.core.svg
   :target: https://github.com/wq/wq.core/network
.. |GitHub Issues| image:: https://img.shields.io/github/issues/wq/wq.core.svg
   :target: https://github.com/wq/wq.core/issues
.. |Travis Build Status| image:: https://img.shields.io/travis/wq/wq.core/master.svg
   :target: https://travis-ci.org/wq/wq.core
